"""
Name: MCS_Test.py
Author: Ryan Urbanowicz - written at Dartmouth College, Hanover, NH, USA 
Note: Code primarily based on python XCS authored by Jose Antonio Martin H. <jamartin@dia.fi.upm.es>
Contact: ryan.j.urbanowicz@darmouth.edu
Created: 3/20/2009
Updated: 10/15/2013
Description: A testing replacement for MCS_Main.py to run MCS from Eclipse. 
---------------------------------------------------------------------------------------------------------------------------------------------------------
MCS Version 1.0: A Python implementation of the MCS learning classifier system algorithm implemented for SNP genetic data mining and classification tasks.
Copyright (C) 2013 Ryan Urbanowicz 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the 
Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABLILITY 
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
---------------------------------------------------------------------------------------------------------------------------------------------------------
"""

#!/usr/bin/env python

#Import modules
from MCS import *
from MCS_GHEnvironment import *
    
def main():
    #RUN PARAMETERS
    graphPerformance = False
    trainData = "2_1000_0_1600_0_0_CV_0_Train.txt"
    testData = "2_1000_0_1600_0_0_CV_0_Test.txt"
    outProg = "GH_MCS_ProgressTrack"
    outPop = "GH_MCS_PopulationOut"
    bitLength = 1    
    reward = 1000
    CVpartitions = 10
    iterInput = '1000.2000'
    trackCycles = 'Default' #set tracking cycles to number of data samples
    #trackCycles = 50
    pop = 1000
    sub = 1
    select = 1
    
    #Figure out the iteration stops for evaluation, and the max iterations.
    iterList = iterInput.split('.')
    for i in range(len(iterList)):
        iterList[i] = int(iterList[i])
    lastIter = iterList[len(iterList)-1]    

    #Sets up up algorithm to be run.
    e = GHEnvironment(trainData,testData,bitLength,reward)
    sampleSize = e.getNrSamples()
    mcs = MCS(e, outProg, outPop, bitLength, CVpartitions, graphPerformance)
    
    #Set some MCS parameters.
    if trackCycles == 'Default':
        mcs.setTrackingIterations(sampleSize)
    else:
        mcs.setTrackingIterations(trackCycles)
    mcs.setNumberOfTrials(lastIter,iterList)   
    mcs.setPopulationSize(pop)
    mcs.setSelection(select)     

    #Run the MCS Algorithm 
    mcs.runMCS()
     
if __name__ == '__main__':
    main()
